@@ -1,66 +1,28 @@
 package Dancer2::Plugin::DBIC;
 
-our $VERSION = '0.0008'; # VERSION
+our $VERSION = '0.0009'; # VERSION
 
 use strict;
 use warnings;
 use utf8;
-use Dancer2::Plugin qw(:no_dsl);
-use Module::Load;
+use Dancer2::Plugin;
+use DBICx::Sugar;
 
-my $schemas = {};
-
-sub schema {
+sub _schema {
     my ($dsl, $name) = @_;
-    my $cfg = plugin_setting;
-
-    if (not defined $name) {
-        if (keys %$cfg == 1) {
-            ($name) = keys %$cfg;
-        } elsif (keys %$cfg) {
-            $name = "default";
-        } else {
-            die "No schemas are configured";
-        }
-    }
-
-    return $schemas->{$name} if $schemas->{$name};
-
-    my $options = $cfg->{$name} or die "The schema $name is not configured";
-
-    my @conn_info = $options->{connect_info}
-        ? @{$options->{connect_info}}
-        : @$options{qw(dsn user password options)};
-    if ( exists $options->{pass} ) {
-        warn "The pass option is deprecated. Use password instead.";
-        $conn_info[2] = $options->{pass};
-    }
-
-    if ( my $schema_class = $options->{schema_class} ) {
-        $schema_class =~ s/-/::/g;
-        eval { load $schema_class };
-        die "Could not load schema_class $schema_class" if $@;
-        $schemas->{$name} = $schema_class->connect(@conn_info)
-    } else {
-        my $dbic_loader = 'DBIx::Class::Schema::Loader';
-        eval { load $dbic_loader };
-        die "You must provide a schema_class option or install $dbic_loader."
-            if $@;
-        $dbic_loader->naming('v7');
-        $schemas->{$name} = DBIx::Class::Schema::Loader->connect(@conn_info);
-    }
-
-    return $schemas->{$name};
+    DBICx::Sugar::config( plugin_setting );
+    return DBICx::Sugar::schema($name);
 };
 
-sub resultset {
+sub _rset {
     my ($dsl, $rset_name) = @_;
     return schema($dsl)->resultset($rset_name);
+    return DBICx::Sugar::schema->resultset($rset_name);
 }
 
-register schema    => \&schema;
-register resultset => \&resultset;
-register rset      => \&resultset;
+register schema    => \&_schema;
+register resultset => \&_rset;
+register rset      => \&_rset;
 register_plugin;
 
 # ABSTRACT: DBIx::Class interface for Dancer2 applications
@@ -80,7 +42,7 @@ Dancer2::Plugin::DBIC - DBIx::Class interface for Dancer2 applications
 
 =head1 VERSION
 
-version 0.0008
+version 0.0009
 
 =head1 SYNOPSIS
 
@@ -113,6 +75,8 @@ You just need to configure your database connection information.
 For performance, schema objects are cached in memory
 and are lazy loaded the first time they are accessed.
 
+This plugin is a thin wrapper around L<DBICx::Sugar>.
+
 =head1 CONFIGURATION
 
 Configuration can be done in your L<Dancer2> config file.
@@ -231,6 +195,16 @@ from the root of your project directory:
 
 For that example, your C<schema_class> setting would be C<Foo::Schema>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+L<DBICx::Sugar>
+
+=back
+
 =head1 CONTRIBUTORS
 
 =over 4
